@@ -1,6 +1,4 @@
-#  $Id: iso9660.py,v 1.12 2008/05/01 16:55:03 karl Exp $
-#
-#  Copyright (C) 2006, 2008 Rocky Bernstein <rocky@gnu.org>
+#  Copyright (C) 2006, 2008, 2010 Rocky Bernstein <rocky@gnu.org>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -496,5 +494,12 @@ class ISO9660:
                 values = pyiso9660.fs_stat_translate(self.cd, path)
             else:
                 values = pyiso9660.fs_stat(self.cd, path)
-            return stat_array_to_dict(values[0], values[1], values[2],
-                                      values[3], values[4])
+                pass
+            if values:
+                return stat_array_to_dict(values[0], values[1], values[2],
+                                          values[3], values[4])
+            else:
+                return None
+            pass
+        pass
+    pass
